@@ -42,7 +42,7 @@ from ..algorithms.stereo import MoleculeStereo
 from ..algorithms.tautomers import Tautomers
 from ..algorithms.x3dom import X3domMolecule
 from ..exceptions import MappingError, ValenceError
-from ..periodictable import DynamicElement, Element, QueryElement
+from ..periodictable import DynamicElement, Element, QueryElement, H
 
 
 class MoleculeContainer(MoleculeStereo, Graph[Element, Bond], Aromatize, StandardizeMolecule, MoleculeSmiles,
@@ -204,7 +204,7 @@ class MoleculeContainer(MoleculeStereo, Graph[Element, Bond], Aromatize, Standar
 
     @cached_property
     def molecular_mass(self) -> float:
-        return sum(x.atomic_mass for x in self._atoms.values())
+        return sum(x.atomic_mass for x in self._atoms.values()) + sum(self._hydrogens.values()) * H().atomic_mass
 
     @cached_property
     def brutto(self) -> Dict[str, int]:
@@ -223,7 +223,7 @@ class MoleculeContainer(MoleculeStereo, Graph[Element, Bond], Aromatize, Standar
                      and all(bonds[n][m] == 4 for n, m in zip(ring, ring[1:])))
 
     def add_atom(self, atom: Union[Element, int, str], *args, charge=0, is_radical=False,
-                 xy: Tuple[float, float] = (0., 0.), **kwargs):
+                 xy: Tuple[float, float] = (0., 0.), _skip_hydrogen_calculation=False, **kwargs):
         """
         Add new atom.
         """
@@ -241,7 +241,9 @@ class MoleculeContainer(MoleculeStereo, Graph[Element, Bond], Aromatize, Standar
         self._plane[n] = xy
         self._conformers.clear()  # clean conformers. need full recalculation for new system
 
-        if atom.atomic_number != 1:
+        if _skip_hydrogen_calculation:
+            self._hydrogens[n] = None
+        elif atom.atomic_number != 1:
             try:
                 rules = atom.valence_rules(charge, is_radical, 0)
             except ValenceError:
@@ -252,7 +254,7 @@ class MoleculeContainer(MoleculeStereo, Graph[Element, Bond], Aromatize, Standar
             self._hydrogens[n] = 0
         return n
 
-    def add_bond(self, n, m, bond: Union[Bond, int]):
+    def add_bond(self, n, m, bond: Union[Bond, int], *, _skip_hydrogen_calculation=False):
         """
         Connect atoms with bonds.
 
@@ -267,6 +269,9 @@ class MoleculeContainer(MoleculeStereo, Graph[Element, Bond], Aromatize, Standar
         super().add_bond(n, m, bond)
         self._conformers.clear()  # clean conformers. need full recalculation for new system
 
+        if _skip_hydrogen_calculation:  # skip stereo fixing too
+            return
+
         self._calc_implicit(n)
         self._calc_implicit(m)
 
